# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .build_pipeline_stage_run_progress import BuildPipelineStageRunProgress
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WaitStageRunProgress(BuildPipelineStageRunProgress):
    """
    Specifies Wait stage specific run details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new WaitStageRunProgress object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.WaitStageRunProgress.build_pipeline_stage_type` attribute
        of this class is ``WAIT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stage_display_name:
            The value to assign to the stage_display_name property of this WaitStageRunProgress.
        :type stage_display_name: str

        :param build_pipeline_stage_type:
            The value to assign to the build_pipeline_stage_type property of this WaitStageRunProgress.
        :type build_pipeline_stage_type: str

        :param build_pipeline_stage_id:
            The value to assign to the build_pipeline_stage_id property of this WaitStageRunProgress.
        :type build_pipeline_stage_id: str

        :param time_started:
            The value to assign to the time_started property of this WaitStageRunProgress.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this WaitStageRunProgress.
        :type time_finished: datetime

        :param status:
            The value to assign to the status property of this WaitStageRunProgress.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED"
        :type status: str

        :param build_pipeline_stage_predecessors:
            The value to assign to the build_pipeline_stage_predecessors property of this WaitStageRunProgress.
        :type build_pipeline_stage_predecessors: oci.devops.models.BuildPipelineStagePredecessorCollection

        """
        self.swagger_types = {
            'stage_display_name': 'str',
            'build_pipeline_stage_type': 'str',
            'build_pipeline_stage_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'status': 'str',
            'build_pipeline_stage_predecessors': 'BuildPipelineStagePredecessorCollection'
        }

        self.attribute_map = {
            'stage_display_name': 'stageDisplayName',
            'build_pipeline_stage_type': 'buildPipelineStageType',
            'build_pipeline_stage_id': 'buildPipelineStageId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'status': 'status',
            'build_pipeline_stage_predecessors': 'buildPipelineStagePredecessors'
        }

        self._stage_display_name = None
        self._build_pipeline_stage_type = None
        self._build_pipeline_stage_id = None
        self._time_started = None
        self._time_finished = None
        self._status = None
        self._build_pipeline_stage_predecessors = None
        self._build_pipeline_stage_type = 'WAIT'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .config import Config
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApdexRules(Config):
    """
    The set of Apdex rules to be used in Apdex computation. In the current version, only one rule set can exist in the
    configuration. This may change in the future.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApdexRules object with values from keyword arguments. The default value of the :py:attr:`~oci.apm_config.models.ApdexRules.config_type` attribute
        of this class is ``APDEX`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ApdexRules.
        :type id: str

        :param config_type:
            The value to assign to the config_type property of this ApdexRules.
            Allowed values for this property are: "SPAN_FILTER", "METRIC_GROUP", "APDEX"
        :type config_type: str

        :param time_created:
            The value to assign to the time_created property of this ApdexRules.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ApdexRules.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ApdexRules.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ApdexRules.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this ApdexRules.
        :type display_name: str

        :param rules:
            The value to assign to the rules property of this ApdexRules.
        :type rules: list[oci.apm_config.models.Apdex]

        """
        self.swagger_types = {
            'id': 'str',
            'config_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'rules': 'list[Apdex]'
        }

        self.attribute_map = {
            'id': 'id',
            'config_type': 'configType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'rules': 'rules'
        }

        self._id = None
        self._config_type = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._display_name = None
        self._rules = None
        self._config_type = 'APDEX'

    @property
    def display_name(self):
        """
        Gets the display_name of this ApdexRules.
        The name by which this rule set can be displayed to the user.


        :return: The display_name of this ApdexRules.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ApdexRules.
        The name by which this rule set can be displayed to the user.


        :param display_name: The display_name of this ApdexRules.
        :type: str
        """
        self._display_name = display_name

    @property
    def rules(self):
        """
        Gets the rules of this ApdexRules.

        :return: The rules of this ApdexRules.
        :rtype: list[oci.apm_config.models.Apdex]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this ApdexRules.

        :param rules: The rules of this ApdexRules.
        :type: list[oci.apm_config.models.Apdex]
        """
        self._rules = rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .billing_schedule_summary import BillingScheduleSummary
from .product import Product

# Maps type names to classes for osub_billing_schedule services.
osub_billing_schedule_type_mapping = {
    "BillingScheduleSummary": BillingScheduleSummary,
    "Product": Product
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDrgRouteDistributionStatementsDetails(object):
    """
    Details request to update statements in a route distribution.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDrgRouteDistributionStatementsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param statements:
            The value to assign to the statements property of this UpdateDrgRouteDistributionStatementsDetails.
        :type statements: list[oci.core.models.UpdateDrgRouteDistributionStatementDetails]

        """
        self.swagger_types = {
            'statements': 'list[UpdateDrgRouteDistributionStatementDetails]'
        }

        self.attribute_map = {
            'statements': 'statements'
        }

        self._statements = None

    @property
    def statements(self):
        """
        **[Required]** Gets the statements of this UpdateDrgRouteDistributionStatementsDetails.
        The route distribution statements to update, and the details to be updated.


        :return: The statements of this UpdateDrgRouteDistributionStatementsDetails.
        :rtype: list[oci.core.models.UpdateDrgRouteDistributionStatementDetails]
        """
        return self._statements

    @statements.setter
    def statements(self, statements):
        """
        Sets the statements of this UpdateDrgRouteDistributionStatementsDetails.
        The route distribution statements to update, and the details to be updated.


        :param statements: The statements of this UpdateDrgRouteDistributionStatementsDetails.
        :type: list[oci.core.models.UpdateDrgRouteDistributionStatementDetails]
        """
        self._statements = statements

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsCategory(object):
    """
    A category into which resources can be placed.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsCategory object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this LogAnalyticsCategory.
        :type name: str

        :param description:
            The value to assign to the description property of this LogAnalyticsCategory.
        :type description: str

        :param display_name:
            The value to assign to the display_name property of this LogAnalyticsCategory.
        :type display_name: str

        :param type:
            The value to assign to the type property of this LogAnalyticsCategory.
        :type type: str

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsCategory.
        :type is_system: bool

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'display_name': 'str',
            'type': 'str',
            'is_system': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'display_name': 'displayName',
            'type': 'type',
            'is_system': 'isSystem'
        }

        self._name = None
        self._description = None
        self._display_name = None
        self._type = None
        self._is_system = None

    @property
    def name(self):
        """
        Gets the name of this LogAnalyticsCategory.
        The unique name that identifies the category.


        :return: The name of this LogAnalyticsCategory.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsCategory.
        The unique name that identifies the category.


        :param name: The name of this LogAnalyticsCategory.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsCategory.
        The category description.


        :return: The description of this LogAnalyticsCategory.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsCategory.
        The category description.


        :param description: The description of this LogAnalyticsCategory.
        :type: str
        """
        self._description = description

    @property
    def display_name(self):
        """
        Gets the display_name of this LogAnalyticsCategory.
        The category display name.


        :return: The display_name of this LogAnalyticsCategory.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LogAnalyticsCategory.
        The category display name.


        :param display_name: The display_name of this LogAnalyticsCategory.
        :type: str
        """
        self._display_name = display_name

    @property
    def type(self):
        """
        Gets the type of this LogAnalyticsCategory.
        The category type. Values include \"PRODUCT\", \"TIER\", \"VENDOR\" and \"GENERIC\".


        :return: The type of this LogAnalyticsCategory.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this LogAnalyticsCategory.
        The category type. Values include \"PRODUCT\", \"TIER\", \"VENDOR\" and \"GENERIC\".


        :param type: The type of this LogAnalyticsCategory.
        :type: str
        """
        self._type = type

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsCategory.
        The system flag. A value of false denotes a user-created
        category. A value of true denotes an Oracle-defined category.


        :return: The is_system of this LogAnalyticsCategory.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsCategory.
        The system flag. A value of false denotes a user-created
        category. A value of true denotes an Oracle-defined category.


        :param is_system: The is_system of this LogAnalyticsCategory.
        :type: bool
        """
        self._is_system = is_system

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BatchDetectDominantLanguageResult(object):
    """
    Result of language detect call.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BatchDetectDominantLanguageResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param documents:
            The value to assign to the documents property of this BatchDetectDominantLanguageResult.
        :type documents: list[oci.ai_language.models.DominantLanguageDocumentResult]

        :param errors:
            The value to assign to the errors property of this BatchDetectDominantLanguageResult.
        :type errors: list[oci.ai_language.models.DocumentError]

        """
        self.swagger_types = {
            'documents': 'list[DominantLanguageDocumentResult]',
            'errors': 'list[DocumentError]'
        }

        self.attribute_map = {
            'documents': 'documents',
            'errors': 'errors'
        }

        self._documents = None
        self._errors = None

    @property
    def documents(self):
        """
        **[Required]** Gets the documents of this BatchDetectDominantLanguageResult.
        List of succeeded document response.


        :return: The documents of this BatchDetectDominantLanguageResult.
        :rtype: list[oci.ai_language.models.DominantLanguageDocumentResult]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """
        Sets the documents of this BatchDetectDominantLanguageResult.
        List of succeeded document response.


        :param documents: The documents of this BatchDetectDominantLanguageResult.
        :type: list[oci.ai_language.models.DominantLanguageDocumentResult]
        """
        self._documents = documents

    @property
    def errors(self):
        """
        Gets the errors of this BatchDetectDominantLanguageResult.
        List of failed document response.


        :return: The errors of this BatchDetectDominantLanguageResult.
        :rtype: list[oci.ai_language.models.DocumentError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this BatchDetectDominantLanguageResult.
        List of failed document response.


        :param errors: The errors of this BatchDetectDominantLanguageResult.
        :type: list[oci.ai_language.models.DocumentError]
        """
        self._errors = errors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Metric(object):
    """
    A metric. This a quantitative measurement of an entity.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Metric object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Metric.
        :type name: str

        :param value_source:
            The value to assign to the value_source property of this Metric.
        :type value_source: str

        :param unit:
            The value to assign to the unit property of this Metric.
        :type unit: str

        :param description:
            The value to assign to the description property of this Metric.
        :type description: str

        """
        self.swagger_types = {
            'name': 'str',
            'value_source': 'str',
            'unit': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'value_source': 'valueSource',
            'unit': 'unit',
            'description': 'description'
        }

        self._name = None
        self._value_source = None
        self._unit = None
        self._description = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Metric.
        The name of the metric


        :return: The name of this Metric.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Metric.
        The name of the metric


        :param name: The name of this Metric.
        :type: str
        """
        self._name = name

    @property
    def value_source(self):
        """
        Gets the value_source of this Metric.
        Must be NULL at the moment, and \"name\" must be a known metric.


        :return: The value_source of this Metric.
        :rtype: str
        """
        return self._value_source

    @value_source.setter
    def value_source(self, value_source):
        """
        Sets the value_source of this Metric.
        Must be NULL at the moment, and \"name\" must be a known metric.


        :param value_source: The value_source of this Metric.
        :type: str
        """
        self._value_source = value_source

    @property
    def unit(self):
        """
        Gets the unit of this Metric.
        The unit of the metric


        :return: The unit of this Metric.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this Metric.
        The unit of the metric


        :param unit: The unit of this Metric.
        :type: str
        """
        self._unit = unit

    @property
    def description(self):
        """
        Gets the description of this Metric.
        A description of the metric


        :return: The description of this Metric.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Metric.
        A description of the metric


        :param description: The description of this Metric.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDeploymentDetails(object):
    """
    The information to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDeploymentDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.UpdateSingleDeployStageDeploymentDetails`
        * :class:`~oci.devops.models.UpdateDeployPipelineRedeploymentDetails`
        * :class:`~oci.devops.models.UpdateDeployPipelineDeploymentDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deployment_type:
            The value to assign to the deployment_type property of this UpdateDeploymentDetails.
        :type deployment_type: str

        :param display_name:
            The value to assign to the display_name property of this UpdateDeploymentDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDeploymentDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDeploymentDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'deployment_type': 'str',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'deployment_type': 'deploymentType',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._deployment_type = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['deploymentType']

        if type == 'SINGLE_STAGE_DEPLOYMENT':
            return 'UpdateSingleDeployStageDeploymentDetails'

        if type == 'PIPELINE_REDEPLOYMENT':
            return 'UpdateDeployPipelineRedeploymentDetails'

        if type == 'PIPELINE_DEPLOYMENT':
            return 'UpdateDeployPipelineDeploymentDetails'
        else:
            return 'UpdateDeploymentDetails'

    @property
    def deployment_type(self):
        """
        **[Required]** Gets the deployment_type of this UpdateDeploymentDetails.
        Specifies type for this deployment.


        :return: The deployment_type of this UpdateDeploymentDetails.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this UpdateDeploymentDetails.
        Specifies type for this deployment.


        :param deployment_type: The deployment_type of this UpdateDeploymentDetails.
        :type: str
        """
        self._deployment_type = deployment_type

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateDeploymentDetails.
        Deployment display name. Avoid entering confidential information.


        :return: The display_name of this UpdateDeploymentDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateDeploymentDetails.
        Deployment display name. Avoid entering confidential information.


        :param display_name: The display_name of this UpdateDeploymentDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateDeploymentDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateDeploymentDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateDeploymentDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.  See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateDeploymentDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateDeploymentDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateDeploymentDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateDeploymentDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateDeploymentDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TopologyAssociatedWithRelationshipDetails(object):
    """
    Defines association details for an `associatedWith` relationship.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TopologyAssociatedWithRelationshipDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param via:
            The value to assign to the via property of this TopologyAssociatedWithRelationshipDetails.
        :type via: list[str]

        """
        self.swagger_types = {
            'via': 'list[str]'
        }

        self.attribute_map = {
            'via': 'via'
        }

        self._via = None

    @property
    def via(self):
        """
        Gets the via of this TopologyAssociatedWithRelationshipDetails.
        The `OCID`__ of the entities via which the relationship is created. For example an instance is associated with a network security group via the VNIC attachment and the VNIC.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The via of this TopologyAssociatedWithRelationshipDetails.
        :rtype: list[str]
        """
        return self._via

    @via.setter
    def via(self, via):
        """
        Sets the via of this TopologyAssociatedWithRelationshipDetails.
        The `OCID`__ of the entities via which the relationship is created. For example an instance is associated with a network security group via the VNIC attachment and the VNIC.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param via: The via of this TopologyAssociatedWithRelationshipDetails.
        :type: list[str]
        """
        self._via = via

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Template(object):
    """
    The properties that define a template. A template is a pre-built Terraform configuration that provisions a set of resources used in a common scenario.
    """

    #: A constant which can be used with the lifecycle_state property of a Template.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new Template object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Template.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Template.
        :type compartment_id: str

        :param category_id:
            The value to assign to the category_id property of this Template.
        :type category_id: str

        :param display_name:
            The value to assign to the display_name property of this Template.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Template.
        :type description: str

        :param long_description:
            The value to assign to the long_description property of this Template.
        :type long_description: str

        :param is_free_tier:
            The value to assign to the is_free_tier property of this Template.
        :type is_free_tier: bool

        :param time_created:
            The value to assign to the time_created property of this Template.
        :type time_created: datetime

        :param template_config_source:
            The value to assign to the template_config_source property of this Template.
        :type template_config_source: oci.resource_manager.models.TemplateConfigSource

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Template.
            Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Template.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Template.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'category_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'long_description': 'str',
            'is_free_tier': 'bool',
            'time_created': 'datetime',
            'template_config_source': 'TemplateConfigSource',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'category_id': 'categoryId',
            'display_name': 'displayName',
            'description': 'description',
            'long_description': 'longDescription',
            'is_free_tier': 'isFreeTier',
            'time_created': 'timeCreated',
            'template_config_source': 'templateConfigSource',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._category_id = None
        self._display_name = None
        self._description = None
        self._long_description = None
        self._is_free_tier = None
        self._time_created = None
        self._template_config_source = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Template.
        Unique identifier (`OCID`__) for the template.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Template.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Template.
        Unique identifier (`OCID`__) for the template.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Template.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Template.
        The `OCID`__ of the compartment containing this template.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Template.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Template.
        The `OCID`__ of the compartment containing this template.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Template.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def category_id(self):
        """
        Gets the category_id of this Template.
        Unique identifier for the category where the template is located.
        Possible values are `0` (Quick Starts), `1` (Service), `2` (Architecture), and `3` (Private).


        :return: The category_id of this Template.
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """
        Sets the category_id of this Template.
        Unique identifier for the category where the template is located.
        Possible values are `0` (Quick Starts), `1` (Service), `2` (Architecture), and `3` (Private).


        :param category_id: The category_id of this Template.
        :type: str
        """
        self._category_id = category_id

    @property
    def display_name(self):
        """
        Gets the display_name of this Template.
        Human-readable name of the template.


        :return: The display_name of this Template.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Template.
        Human-readable name of the template.


        :param display_name: The display_name of this Template.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Template.
        Brief description of the template.


        :return: The description of this Template.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Template.
        Brief description of the template.


        :param description: The description of this Template.
        :type: str
        """
        self._description = description

    @property
    def long_description(self):
        """
        Gets the long_description of this Template.
        Detailed description of the template. This description is displayed in the Console page listing templates when the template is expanded. Avoid entering confidential information.


        :return: The long_description of this Template.
        :rtype: str
        """
        return self._long_description

    @long_description.setter
    def long_description(self, long_description):
        """
        Sets the long_description of this Template.
        Detailed description of the template. This description is displayed in the Console page listing templates when the template is expanded. Avoid entering confidential information.


        :param long_description: The long_description of this Template.
        :type: str
        """
        self._long_description = long_description

    @property
    def is_free_tier(self):
        """
        Gets the is_free_tier of this Template.
        whether the template will work for free tier tenancy.


        :return: The is_free_tier of this Template.
        :rtype: bool
        """
        return self._is_free_tier

    @is_free_tier.setter
    def is_free_tier(self, is_free_tier):
        """
        Sets the is_free_tier of this Template.
        whether the template will work for free tier tenancy.


        :param is_free_tier: The is_free_tier of this Template.
        :type: bool
        """
        self._is_free_tier = is_free_tier

    @property
    def time_created(self):
        """
        Gets the time_created of this Template.
        The date and time at which the template was created.
        Format is defined by RFC3339.
        Example: `2020-11-25T21:10:29.600Z`


        :return: The time_created of this Template.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Template.
        The date and time at which the template was created.
        Format is defined by RFC3339.
        Example: `2020-11-25T21:10:29.600Z`


        :param time_created: The time_created of this Template.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def template_config_source(self):
        """
        Gets the template_config_source of this Template.

        :return: The template_config_source of this Template.
        :rtype: oci.resource_manager.models.TemplateConfigSource
        """
        return self._template_config_source

    @template_config_source.setter
    def template_config_source(self, template_config_source):
        """
        Sets the template_config_source of this Template.

        :param template_config_source: The template_config_source of this Template.
        :type: oci.resource_manager.models.TemplateConfigSource
        """
        self._template_config_source = template_config_source

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Template.
        The current lifecycle state of the template.

        Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Template.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Template.
        The current lifecycle state of the template.


        :param lifecycle_state: The lifecycle_state of this Template.
        :type: str
        """
        allowed_values = ["ACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Template.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Template.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Template.
        Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Template.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Template.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Template.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Template.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Template.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .web_app_firewall_policy_rule import WebAppFirewallPolicyRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionRule(WebAppFirewallPolicyRule):
    """
    Rule that represents Request/Response Protection.
    Only actions of the following types are allowed to be referenced in this rule:
    * CHECK
    * RETURN_HTTP_RESPONSE
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionRule object with values from keyword arguments. The default value of the :py:attr:`~oci.waf.models.ProtectionRule.type` attribute
        of this class is ``PROTECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ProtectionRule.
            Allowed values for this property are: "ACCESS_CONTROL", "PROTECTION", "REQUEST_RATE_LIMITING"
        :type type: str

        :param name:
            The value to assign to the name property of this ProtectionRule.
        :type name: str

        :param condition_language:
            The value to assign to the condition_language property of this ProtectionRule.
            Allowed values for this property are: "JMESPATH"
        :type condition_language: str

        :param condition:
            The value to assign to the condition property of this ProtectionRule.
        :type condition: str

        :param action_name:
            The value to assign to the action_name property of this ProtectionRule.
        :type action_name: str

        :param protection_capabilities:
            The value to assign to the protection_capabilities property of this ProtectionRule.
        :type protection_capabilities: list[oci.waf.models.ProtectionCapability]

        :param protection_capability_settings:
            The value to assign to the protection_capability_settings property of this ProtectionRule.
        :type protection_capability_settings: oci.waf.models.ProtectionCapabilitySettings

        """
        self.swagger_types = {
            'type': 'str',
            'name': 'str',
            'condition_language': 'str',
            'condition': 'str',
            'action_name': 'str',
            'protection_capabilities': 'list[ProtectionCapability]',
            'protection_capability_settings': 'ProtectionCapabilitySettings'
        }

        self.attribute_map = {
            'type': 'type',
            'name': 'name',
            'condition_language': 'conditionLanguage',
            'condition': 'condition',
            'action_name': 'actionName',
            'protection_capabilities': 'protectionCapabilities',
            'protection_capability_settings': 'protectionCapabilitySettings'
        }

        self._type = None
        self._name = None
        self._condition_language = None
        self._condition = None
        self._action_name = None
        self._protection_capabilities = None
        self._protection_capability_settings = None
        self._type = 'PROTECTION'

    @property
    def protection_capabilities(self):
        """
        **[Required]** Gets the protection_capabilities of this ProtectionRule.
        An ordered list that references OCI-managed protection capabilities.
        Referenced protection capabilities are executed in order of appearance.
        The array cannot contain entries with the same pair of capability key and version more than once.


        :return: The protection_capabilities of this ProtectionRule.
        :rtype: list[oci.waf.models.ProtectionCapability]
        """
        return self._protection_capabilities

    @protection_capabilities.setter
    def protection_capabilities(self, protection_capabilities):
        """
        Sets the protection_capabilities of this ProtectionRule.
        An ordered list that references OCI-managed protection capabilities.
        Referenced protection capabilities are executed in order of appearance.
        The array cannot contain entries with the same pair of capability key and version more than once.


        :param protection_capabilities: The protection_capabilities of this ProtectionRule.
        :type: list[oci.waf.models.ProtectionCapability]
        """
        self._protection_capabilities = protection_capabilities

    @property
    def protection_capability_settings(self):
        """
        Gets the protection_capability_settings of this ProtectionRule.

        :return: The protection_capability_settings of this ProtectionRule.
        :rtype: oci.waf.models.ProtectionCapabilitySettings
        """
        return self._protection_capability_settings

    @protection_capability_settings.setter
    def protection_capability_settings(self, protection_capability_settings):
        """
        Sets the protection_capability_settings of this ProtectionRule.

        :param protection_capability_settings: The protection_capability_settings of this ProtectionRule.
        :type: oci.waf.models.ProtectionCapabilitySettings
        """
        self._protection_capability_settings = protection_capability_settings

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .web_app_firewall_policy_rule import WebAppFirewallPolicyRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AccessControlRule(WebAppFirewallPolicyRule):
    """
    Rule that represents Request/Response Access Control.
    Only actions of the following types are allowed to be referenced in this rule:
    * CHECK
    * ALLOW
    * RETURN_HTTP_RESPONSE
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AccessControlRule object with values from keyword arguments. The default value of the :py:attr:`~oci.waf.models.AccessControlRule.type` attribute
        of this class is ``ACCESS_CONTROL`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AccessControlRule.
            Allowed values for this property are: "ACCESS_CONTROL", "PROTECTION", "REQUEST_RATE_LIMITING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param name:
            The value to assign to the name property of this AccessControlRule.
        :type name: str

        :param condition_language:
            The value to assign to the condition_language property of this AccessControlRule.
            Allowed values for this property are: "JMESPATH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type condition_language: str

        :param condition:
            The value to assign to the condition property of this AccessControlRule.
        :type condition: str

        :param action_name:
            The value to assign to the action_name property of this AccessControlRule.
        :type action_name: str

        """
        self.swagger_types = {
            'type': 'str',
            'name': 'str',
            'condition_language': 'str',
            'condition': 'str',
            'action_name': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'name': 'name',
            'condition_language': 'conditionLanguage',
            'condition': 'condition',
            'action_name': 'actionName'
        }

        self._type = None
        self._name = None
        self._condition_language = None
        self._condition = None
        self._action_name = None
        self._type = 'ACCESS_CONTROL'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceInventory(object):
    """
    Inventory of JMS resources in a compartment during a specified time period.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceInventory object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param active_fleet_count:
            The value to assign to the active_fleet_count property of this ResourceInventory.
        :type active_fleet_count: int

        :param managed_instance_count:
            The value to assign to the managed_instance_count property of this ResourceInventory.
        :type managed_instance_count: int

        :param jre_count:
            The value to assign to the jre_count property of this ResourceInventory.
        :type jre_count: int

        :param installation_count:
            The value to assign to the installation_count property of this ResourceInventory.
        :type installation_count: int

        :param application_count:
            The value to assign to the application_count property of this ResourceInventory.
        :type application_count: int

        """
        self.swagger_types = {
            'active_fleet_count': 'int',
            'managed_instance_count': 'int',
            'jre_count': 'int',
            'installation_count': 'int',
            'application_count': 'int'
        }

        self.attribute_map = {
            'active_fleet_count': 'activeFleetCount',
            'managed_instance_count': 'managedInstanceCount',
            'jre_count': 'jreCount',
            'installation_count': 'installationCount',
            'application_count': 'applicationCount'
        }

        self._active_fleet_count = None
        self._managed_instance_count = None
        self._jre_count = None
        self._installation_count = None
        self._application_count = None

    @property
    def active_fleet_count(self):
        """
        **[Required]** Gets the active_fleet_count of this ResourceInventory.
        The number of _active_ fleets.


        :return: The active_fleet_count of this ResourceInventory.
        :rtype: int
        """
        return self._active_fleet_count

    @active_fleet_count.setter
    def active_fleet_count(self, active_fleet_count):
        """
        Sets the active_fleet_count of this ResourceInventory.
        The number of _active_ fleets.


        :param active_fleet_count: The active_fleet_count of this ResourceInventory.
        :type: int
        """
        self._active_fleet_count = active_fleet_count

    @property
    def managed_instance_count(self):
        """
        **[Required]** Gets the managed_instance_count of this ResourceInventory.
        The number of managed instances.


        :return: The managed_instance_count of this ResourceInventory.
        :rtype: int
        """
        return self._managed_instance_count

    @managed_instance_count.setter
    def managed_instance_count(self, managed_instance_count):
        """
        Sets the managed_instance_count of this ResourceInventory.
        The number of managed instances.


        :param managed_instance_count: The managed_instance_count of this ResourceInventory.
        :type: int
        """
        self._managed_instance_count = managed_instance_count

    @property
    def jre_count(self):
        """
        **[Required]** Gets the jre_count of this ResourceInventory.
        The number of Java Runtimes.


        :return: The jre_count of this ResourceInventory.
        :rtype: int
        """
        return self._jre_count

    @jre_count.setter
    def jre_count(self, jre_count):
        """
        Sets the jre_count of this ResourceInventory.
        The number of Java Runtimes.


        :param jre_count: The jre_count of this ResourceInventory.
        :type: int
        """
        self._jre_count = jre_count

    @property
    def installation_count(self):
        """
        **[Required]** Gets the installation_count of this ResourceInventory.
        The number of Java installations.


        :return: The installation_count of this ResourceInventory.
        :rtype: int
        """
        return self._installation_count

    @installation_count.setter
    def installation_count(self, installation_count):
        """
        Sets the installation_count of this ResourceInventory.
        The number of Java installations.


        :param installation_count: The installation_count of this ResourceInventory.
        :type: int
        """
        self._installation_count = installation_count

    @property
    def application_count(self):
        """
        **[Required]** Gets the application_count of this ResourceInventory.
        The number of applications.


        :return: The application_count of this ResourceInventory.
        :rtype: int
        """
        return self._application_count

    @application_count.setter
    def application_count(self, application_count):
        """
        Sets the application_count of this ResourceInventory.
        The number of applications.


        :param application_count: The application_count of this ResourceInventory.
        :type: int
        """
        self._application_count = application_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OnBehalfOfRequest(object):
    """
    OnBehalfOfRequest model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OnBehalfOfRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param request_headers:
            The value to assign to the request_headers property of this OnBehalfOfRequest.
        :type request_headers: dict(str, list[str])

        :param target_service_name:
            The value to assign to the target_service_name property of this OnBehalfOfRequest.
        :type target_service_name: str

        :param obo_token:
            The value to assign to the obo_token property of this OnBehalfOfRequest.
        :type obo_token: str

        :param expiration:
            The value to assign to the expiration property of this OnBehalfOfRequest.
        :type expiration: str

        """
        self.swagger_types = {
            'request_headers': 'dict(str, list[str])',
            'target_service_name': 'str',
            'obo_token': 'str',
            'expiration': 'str'
        }

        self.attribute_map = {
            'request_headers': 'requestHeaders',
            'target_service_name': 'targetServiceName',
            'obo_token': 'oboToken',
            'expiration': 'expiration'
        }

        self._request_headers = None
        self._target_service_name = None
        self._obo_token = None
        self._expiration = None

    @property
    def request_headers(self):
        """
        **[Required]** Gets the request_headers of this OnBehalfOfRequest.
        The signed headers of the customer call.


        :return: The request_headers of this OnBehalfOfRequest.
        :rtype: dict(str, list[str])
        """
        return self._request_headers

    @request_headers.setter
    def request_headers(self, request_headers):
        """
        Sets the request_headers of this OnBehalfOfRequest.
        The signed headers of the customer call.


        :param request_headers: The request_headers of this OnBehalfOfRequest.
        :type: dict(str, list[str])
        """
        self._request_headers = request_headers

    @property
    def target_service_name(self):
        """
        **[Required]** Gets the target_service_name of this OnBehalfOfRequest.
        The name of the target service.


        :return: The target_service_name of this OnBehalfOfRequest.
        :rtype: str
        """
        return self._target_service_name

    @target_service_name.setter
    def target_service_name(self, target_service_name):
        """
        Sets the target_service_name of this OnBehalfOfRequest.
        The name of the target service.


        :param target_service_name: The target_service_name of this OnBehalfOfRequest.
        :type: str
        """
        self._target_service_name = target_service_name

    @property
    def obo_token(self):
        """
        Gets the obo_token of this OnBehalfOfRequest.
        If you have an obo token already, exchange that for a new obo token.


        :return: The obo_token of this OnBehalfOfRequest.
        :rtype: str
        """
        return self._obo_token

    @obo_token.setter
    def obo_token(self, obo_token):
        """
        Sets the obo_token of this OnBehalfOfRequest.
        If you have an obo token already, exchange that for a new obo token.


        :param obo_token: The obo_token of this OnBehalfOfRequest.
        :type: str
        """
        self._obo_token = obo_token

    @property
    def expiration(self):
        """
        Gets the expiration of this OnBehalfOfRequest.
        A duration for which the obo token is requested to be valid.


        :return: The expiration of this OnBehalfOfRequest.
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """
        Sets the expiration of this OnBehalfOfRequest.
        A duration for which the obo token is requested to be valid.


        :param expiration: The expiration of this OnBehalfOfRequest.
        :type: str
        """
        self._expiration = expiration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeliverArtifact(object):
    """
    Artifact information that need to be pushed to the artifactory stores.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeliverArtifact object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param artifact_name:
            The value to assign to the artifact_name property of this DeliverArtifact.
        :type artifact_name: str

        :param artifact_id:
            The value to assign to the artifact_id property of this DeliverArtifact.
        :type artifact_id: str

        """
        self.swagger_types = {
            'artifact_name': 'str',
            'artifact_id': 'str'
        }

        self.attribute_map = {
            'artifact_name': 'artifactName',
            'artifact_id': 'artifactId'
        }

        self._artifact_name = None
        self._artifact_id = None

    @property
    def artifact_name(self):
        """
        **[Required]** Gets the artifact_name of this DeliverArtifact.
        Name of the artifact specified in the build_spec.yaml file.


        :return: The artifact_name of this DeliverArtifact.
        :rtype: str
        """
        return self._artifact_name

    @artifact_name.setter
    def artifact_name(self, artifact_name):
        """
        Sets the artifact_name of this DeliverArtifact.
        Name of the artifact specified in the build_spec.yaml file.


        :param artifact_name: The artifact_name of this DeliverArtifact.
        :type: str
        """
        self._artifact_name = artifact_name

    @property
    def artifact_id(self):
        """
        **[Required]** Gets the artifact_id of this DeliverArtifact.
        Artifact identifier that contains the artifact definition.


        :return: The artifact_id of this DeliverArtifact.
        :rtype: str
        """
        return self._artifact_id

    @artifact_id.setter
    def artifact_id(self, artifact_id):
        """
        Sets the artifact_id of this DeliverArtifact.
        Artifact identifier that contains the artifact definition.


        :param artifact_id: The artifact_id of this DeliverArtifact.
        :type: str
        """
        self._artifact_id = artifact_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Currency(object):
    """
    Currency details model
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Currency object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param currency_code:
            The value to assign to the currency_code property of this Currency.
        :type currency_code: str

        :param currency_symbol:
            The value to assign to the currency_symbol property of this Currency.
        :type currency_symbol: str

        :param name:
            The value to assign to the name property of this Currency.
        :type name: str

        :param usd_conversion:
            The value to assign to the usd_conversion property of this Currency.
        :type usd_conversion: float

        :param round_decimal_point:
            The value to assign to the round_decimal_point property of this Currency.
        :type round_decimal_point: float

        """
        self.swagger_types = {
            'currency_code': 'str',
            'currency_symbol': 'str',
            'name': 'str',
            'usd_conversion': 'float',
            'round_decimal_point': 'float'
        }

        self.attribute_map = {
            'currency_code': 'currencyCode',
            'currency_symbol': 'currencySymbol',
            'name': 'name',
            'usd_conversion': 'usdConversion',
            'round_decimal_point': 'roundDecimalPoint'
        }

        self._currency_code = None
        self._currency_symbol = None
        self._name = None
        self._usd_conversion = None
        self._round_decimal_point = None

    @property
    def currency_code(self):
        """
        Gets the currency_code of this Currency.
        Currency code


        :return: The currency_code of this Currency.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this Currency.
        Currency code


        :param currency_code: The currency_code of this Currency.
        :type: str
        """
        self._currency_code = currency_code

    @property
    def currency_symbol(self):
        """
        Gets the currency_symbol of this Currency.
        Currency symbol


        :return: The currency_symbol of this Currency.
        :rtype: str
        """
        return self._currency_symbol

    @currency_symbol.setter
    def currency_symbol(self, currency_symbol):
        """
        Sets the currency_symbol of this Currency.
        Currency symbol


        :param currency_symbol: The currency_symbol of this Currency.
        :type: str
        """
        self._currency_symbol = currency_symbol

    @property
    def name(self):
        """
        Gets the name of this Currency.
        Name of the currency


        :return: The name of this Currency.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Currency.
        Name of the currency


        :param name: The name of this Currency.
        :type: str
        """
        self._name = name

    @property
    def usd_conversion(self):
        """
        Gets the usd_conversion of this Currency.
        USD conversion rate of the currency


        :return: The usd_conversion of this Currency.
        :rtype: float
        """
        return self._usd_conversion

    @usd_conversion.setter
    def usd_conversion(self, usd_conversion):
        """
        Sets the usd_conversion of this Currency.
        USD conversion rate of the currency


        :param usd_conversion: The usd_conversion of this Currency.
        :type: float
        """
        self._usd_conversion = usd_conversion

    @property
    def round_decimal_point(self):
        """
        Gets the round_decimal_point of this Currency.
        Round decimal point


        :return: The round_decimal_point of this Currency.
        :rtype: float
        """
        return self._round_decimal_point

    @round_decimal_point.setter
    def round_decimal_point(self, round_decimal_point):
        """
        Sets the round_decimal_point of this Currency.
        Round decimal point


        :param round_decimal_point: The round_decimal_point of this Currency.
        :type: float
        """
        self._round_decimal_point = round_decimal_point

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConvertToPdbDetails(object):
    """
    Details for converting a non-container database to pluggable database.
    """

    #: A constant which can be used with the action property of a ConvertToPdbDetails.
    #: This constant has a value of "PRECHECK"
    ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the action property of a ConvertToPdbDetails.
    #: This constant has a value of "CONVERT"
    ACTION_CONVERT = "CONVERT"

    #: A constant which can be used with the action property of a ConvertToPdbDetails.
    #: This constant has a value of "SYNC"
    ACTION_SYNC = "SYNC"

    #: A constant which can be used with the action property of a ConvertToPdbDetails.
    #: This constant has a value of "SYNC_ROLLBACK"
    ACTION_SYNC_ROLLBACK = "SYNC_ROLLBACK"

    def __init__(self, **kwargs):
        """
        Initializes a new ConvertToPdbDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action:
            The value to assign to the action property of this ConvertToPdbDetails.
            Allowed values for this property are: "PRECHECK", "CONVERT", "SYNC", "SYNC_ROLLBACK"
        :type action: str

        :param convert_to_pdb_target_details:
            The value to assign to the convert_to_pdb_target_details property of this ConvertToPdbDetails.
        :type convert_to_pdb_target_details: oci.database.models.ConvertToPdbTargetBase

        """
        self.swagger_types = {
            'action': 'str',
            'convert_to_pdb_target_details': 'ConvertToPdbTargetBase'
        }

        self.attribute_map = {
            'action': 'action',
            'convert_to_pdb_target_details': 'convertToPdbTargetDetails'
        }

        self._action = None
        self._convert_to_pdb_target_details = None

    @property
    def action(self):
        """
        **[Required]** Gets the action of this ConvertToPdbDetails.
        The operations used to convert a non-container database to a pluggable database.
        - Use `PRECHECK` to run a pre-check operation on non-container database prior to converting it into a pluggable database.
        - Use `CONVERT` to convert a non-container database into a pluggable database.
        - Use `SYNC` if the non-container database was manually converted into a pluggable database using the dbcli command-line utility. Databases may need to be converted manually if the CONVERT action fails when converting a non-container database using the API.
        - Use `SYNC_ROLLBACK` if the conversion of a non-container database into a pluggable database was manually rolled back using the dbcli command line utility. Conversions may need to be manually rolled back if the CONVERT action fails when converting a non-container database using the API.

        Allowed values for this property are: "PRECHECK", "CONVERT", "SYNC", "SYNC_ROLLBACK"


        :return: The action of this ConvertToPdbDetails.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ConvertToPdbDetails.
        The operations used to convert a non-container database to a pluggable database.
        - Use `PRECHECK` to run a pre-check operation on non-container database prior to converting it into a pluggable database.
        - Use `CONVERT` to convert a non-container database into a pluggable database.
        - Use `SYNC` if the non-container database was manually converted into a pluggable database using the dbcli command-line utility. Databases may need to be converted manually if the CONVERT action fails when converting a non-container database using the API.
        - Use `SYNC_ROLLBACK` if the conversion of a non-container database into a pluggable database was manually rolled back using the dbcli command line utility. Conversions may need to be manually rolled back if the CONVERT action fails when converting a non-container database using the API.


        :param action: The action of this ConvertToPdbDetails.
        :type: str
        """
        allowed_values = ["PRECHECK", "CONVERT", "SYNC", "SYNC_ROLLBACK"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            raise ValueError(
                "Invalid value for `action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._action = action

    @property
    def convert_to_pdb_target_details(self):
        """
        Gets the convert_to_pdb_target_details of this ConvertToPdbDetails.

        :return: The convert_to_pdb_target_details of this ConvertToPdbDetails.
        :rtype: oci.database.models.ConvertToPdbTargetBase
        """
        return self._convert_to_pdb_target_details

    @convert_to_pdb_target_details.setter
    def convert_to_pdb_target_details(self, convert_to_pdb_target_details):
        """
        Sets the convert_to_pdb_target_details of this ConvertToPdbDetails.

        :param convert_to_pdb_target_details: The convert_to_pdb_target_details of this ConvertToPdbDetails.
        :type: oci.database.models.ConvertToPdbTargetBase
        """
        self._convert_to_pdb_target_details = convert_to_pdb_target_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConvertToPdbTargetBase(object):
    """
    Details of the container database in which the converted pluggable database will be located.
    """

    #: A constant which can be used with the target property of a ConvertToPdbTargetBase.
    #: This constant has a value of "NEW_DATABASE"
    TARGET_NEW_DATABASE = "NEW_DATABASE"

    def __init__(self, **kwargs):
        """
        Initializes a new ConvertToPdbTargetBase object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.PdbConversionToNewDatabaseDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target:
            The value to assign to the target property of this ConvertToPdbTargetBase.
            Allowed values for this property are: "NEW_DATABASE"
        :type target: str

        """
        self.swagger_types = {
            'target': 'str'
        }

        self.attribute_map = {
            'target': 'target'
        }

        self._target = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['target']

        if type == 'NEW_DATABASE':
            return 'PdbConversionToNewDatabaseDetails'
        else:
            return 'ConvertToPdbTargetBase'

    @property
    def target(self):
        """
        Gets the target of this ConvertToPdbTargetBase.
        The target container database of the pluggable database created by the database conversion operation. Currently, the database conversion operation only supports creating the pluggable database in a new container database.
         - Use `NEW_DATABASE` to specify that the pluggable database be created within a new container database in the same database home.

        Allowed values for this property are: "NEW_DATABASE"


        :return: The target of this ConvertToPdbTargetBase.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this ConvertToPdbTargetBase.
        The target container database of the pluggable database created by the database conversion operation. Currently, the database conversion operation only supports creating the pluggable database in a new container database.
         - Use `NEW_DATABASE` to specify that the pluggable database be created within a new container database in the same database home.


        :param target: The target of this ConvertToPdbTargetBase.
        :type: str
        """
        allowed_values = ["NEW_DATABASE"]
        if not value_allowed_none_or_none_sentinel(target, allowed_values):
            raise ValueError(
                "Invalid value for `target`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._target = target

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
